@@ -1,4 +1,4 @@
-import _JSXStyle from "styled-jsx/style";
+import _JSXStyle from "next/dist/shared/lib/styled-jsx";
 import Link from "next/link";
 export default function IndexPage() {
     return <div className={"jsx-2339e3d61ab4470c"}>
